package com.mdtexfx.html;

import javafx.scene.Parent;
import javafx.scene.web.WebView;

/**
 * Responsible for displaying an HTML document in a GUI.
 */
public class HtmlPreview extends Parent implements HtmlRenderer {
  /**
   * The GUI to render the HTML as a web page.
   */
  private final WebView mView;

  private static final String HTML_PREFIX = """
      <!DOCTYPE html>
      <html lang='en'><head><title> </title><meta charset='utf-8'/></head>
      <body>
      """;
  private static final String HTML_SUFFIX = "</body></html>";
  private static final int HTML_PREFIX_LENGTH = HTML_PREFIX.length();

  private final StringBuilder mHtmlDocument = new StringBuilder( 65536 );

  public HtmlPreview() {
    // Retain the same prefix each time the HTML content is updated.
    mHtmlDocument.append( HTML_PREFIX );
    mView = new WebView();
    getChildren().add( mView );
  }

  @Override
  public String render( final String html ) {
    mHtmlDocument.setLength( HTML_PREFIX_LENGTH );
    mHtmlDocument.append( html );
    mHtmlDocument.append( HTML_SUFFIX );
    mView.getEngine().loadContent( mHtmlDocument.toString() );
    return html;
  }
}
