package com.mdtexfx.processors;

/**
 * Responsible for not performing any processing on the data.
 */
public class IdentityProcessor extends ExecutorProcessor<String> {
  /**
   * Constructs a new processor that does not perform any transformation on
   * the data to process.
   *
   * @param successor Next {@link Processor} in the chain.
   */
  private IdentityProcessor( final Processor<String> successor ) {
    super( successor );
  }

  public static Processor<String> create(
      final Processor<String> successor, final ProcessorContext context ) {
    return new IdentityProcessor( successor );
  }

  /**
   * Does not perform any processing on the given string.
   *
   * @param s The string to return.
   * @return Returns {@code s} without modification.
   */
  @Override
  public String apply( final String s ) {
    return s;
  }
}
