package com.mdtexfx.processors;

import com.vladsch.flexmark.html.HtmlRenderer;
import com.vladsch.flexmark.parser.Parser;
import com.vladsch.flexmark.util.ast.*;

/**
 * Responsible for transforming Markdown into HTML.
 */
public class MarkdownProcessor extends ExecutorProcessor<String> {
  private final IParse mParser = Parser.builder().build();
  private final IRender mRenderer = HtmlRenderer.builder().build();

  /**
   * Constructs a new processor that converts Markdown to HTML.
   *
   * @param successor The next processor in the chain.
   */
  private MarkdownProcessor( final Processor<String> successor ) {
    super( successor );
  }

  /**
   * Instantiates a new {@link MarkdownProcessor} instance given a
   * {@link Processor} capable of handling HTML.
   *
   * @param successor The {@link Processor} that will handle the HTML output by
   *                  this {@link Processor}.
   * @param context   Ignored.
   * @return An instance of {@link Processor} that can transform Markdown into
   * HTML.
   */
  public static MarkdownProcessor create(
      final Processor<String> successor, final ProcessorContext context ) {
    return new MarkdownProcessor( successor );
  }

  @Override
  public String apply( final String markdown ) {
    return mRenderer.render( mParser.parse( markdown ) );
  }
}
