package com.mdtexfx.processors;

import com.mdtexfx.html.HtmlRenderer;
import com.mdtexfx.io.MediaType;

/**
 * Responsible for bundling components that the {@link ProcessorFactory}
 * requires to create all {@link Processor} chains.
 */
public class ProcessorContext {
  private final MediaType mMediaType;
  private final HtmlRenderer mHtmlRenderer;

  /**
   * Constructs a context used by the {@link ProcessorFactory}.
   *
   * @param mediaType    The {@link MediaType} that directs transformations.
   * @param htmlRenderer Where to write the output HTML.
   */
  public ProcessorContext(
      final MediaType mediaType, final HtmlRenderer htmlRenderer ) {
    assert mediaType != null;
    assert htmlRenderer != null;

    mMediaType = mediaType;
    mHtmlRenderer = htmlRenderer;
  }

  MediaType getMediaType() {
    return mMediaType;
  }

  HtmlRenderer getHtmlRenderer() {
    return mHtmlRenderer;
  }
}
